summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Roberto Fresca <robbie@robertofresca.com>2020-07-31 22:39:41 +0200
committer Roberto Fresca <robbie@robertofresca.com>2020-07-31 22:39:41 +0200
commitf49bb92f3ad33a7a4859dd87fc2542e9e4f18ca6 (patch)
tree160c00ae4e554e17a6e4f967f3852652c63df4e6
parent1d60ecd16ff93e8f7b354783a25a7334e1e6a81c (diff)
New working machines
-------------------- Reflex Cards (English, serial protected) [Roberto Fresca, Ioannis Bampoulas] Card"S" Plural...
-rw-r--r--src/mame/drivers/funworld.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/drivers/funworld.cpp b/src/mame/drivers/funworld.cpp
index 373b7bdafa8..4bfb6384b99 100644
--- a/src/mame/drivers/funworld.cpp
+++ b/src/mame/drivers/funworld.cpp
@@ -119,7 +119,7 @@
* Gratis Poker (V.204, Set 1), Mega Soft, 1995.
* Gratis Poker (V.204, Set 2), Mega Soft, 1995.
* Nkoulit (Gullit) (encrypted GFX), JK Amusement, 1995.
* Reflex Card (English, serial protected), TAB Austria, 1999.
* Royal Card (stealth with NES multigame), bootleg, 1991.
* Royal Card (stealth with MSX multigame), bootleg, 1991.
@@ -7463,7 +7463,7 @@ ROM_END
/*
- Reflex Card (English)
+ Reflex Cards (English)
Need special NVRAM to boot.
Without the factory NVRAM, you can generate one.
@@ -8324,7 +8324,7 @@ GAMEL( 1991, jokcrdep, 0, fw_brick_2, fw_brick1, funworld_state, empt
GAMEL( 199?, gratispk, 0, gratispk, funworld, funworld_state, empty_init, ROT0, "Mega Soft", "Gratis Poker (V.204, Set 1)", 0, layout_jollycrd )
GAMEL( 199?, gratispka, gratispk, gratispk, funworld, funworld_state, empty_init, ROT0, "Mega Soft", "Gratis Poker (V.204, Set 2)", 0, layout_jollycrd )
GAMEL( 1995, nkoulit, royalcrd, royalcd1, royalcrd, funworld_state, init_tabblue, ROT0, "JK Amusement", "Nkoulit (Gullit) (encrypted GFX)", 0, layout_jollycrd )
-GAMEL( 1999, reflexcrd, royalcrd, royalcd1, royalcrd, funworld_state, empty_init, ROT0, "TAB Austria", "Reflex Card (English, serial protected)", 0, layout_jollycrd )
+GAMEL( 1999, reflexcrd, royalcrd, royalcd1, royalcrd, funworld_state, empty_init, ROT0, "TAB Austria", "Reflex Cards (English, serial protected)", 0, layout_jollycrd )
// These are 2-in-1 stealth boards, they can run the Poker game, or, using completely separate hardware on the same PCB, a NES / MSX Multigames!
GAMEL( 1991, royalcrd_nes, royalcrd, royalcd2, royalcrd, funworld_state, empty_init, ROT0, "bootleg", "Royal Card (stealth with NES multigame)", MACHINE_NOT_WORKING, layout_jollycrd )
@@ -119,7 +119,7 @@
* Gratis Poker (V.204, Set 2), Mega Soft, 1995.
* Nkoulit (Gullit) (encrypted GFX), JK Amusement, 1995.
- * Reflex Card (English, serial protected), TAB Austria, 1999.
+ * Reflex Cards (English, serial protected), TAB Austria, 1999.
* Royal Card (stealth with NES multigame), bootleg, 1991.
* Royal Card (stealth with MSX multigame), bootleg, 1991.